( cd opt/kde/share/doc/HTML/en/juk ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/juk ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmix ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmix ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/dragonplayer ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/dragonplayer ; ln -sf /opt/kde/share/doc/HTML/en//common common )
( cd opt/kde/share/doc/HTML/en/kscd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kscd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/lib ; rm -rf libkcddb.so )
( cd opt/kde/lib ; ln -sf libkcddb.so.4 libkcddb.so )
( cd opt/kde/lib ; rm -rf libkcddb.so.4 )
( cd opt/kde/lib ; ln -sf libkcddb.so.4.1.0 libkcddb.so.4 )
( cd opt/kde/lib ; rm -rf libkcompactdisc.so )
( cd opt/kde/lib ; ln -sf libkcompactdisc.so.4 libkcompactdisc.so )
( cd opt/kde/lib ; rm -rf libkcompactdisc.so.4 )
( cd opt/kde/lib ; ln -sf libkcompactdisc.so.4.1.0 libkcompactdisc.so.4 )
( cd opt/kde/lib ; rm -rf libaudiocdplugins.so )
( cd opt/kde/lib ; ln -sf libaudiocdplugins.so.4 libaudiocdplugins.so )
( cd opt/kde/lib ; rm -rf libaudiocdplugins.so.4 )
( cd opt/kde/lib ; ln -sf libaudiocdplugins.so.4.1.0 libaudiocdplugins.so.4 )
